==> fengoffice_1.7.5.zip: fengoffice/language/es_la/objects.php <==
<?php return array(
	'user' => 'Usuario',
	'group' => 'Grupo',
	'groups' => 'Grupos',
	'users' => 'Usuarios',
	'member' => 'Miembro',
	'members' => 'Miembros',
	'company' => 'Empresa',
	'companies' => 'Empresa',
	'client' => 'Cliente',
	'clients' => 'Clientes',
	'package' => 'Paquete',
	'project' => 'Espacio',
	'projects' => 'Espacio',
	'message' => 'Nota',
	'messages' => 'Notas',
	'comment' => 'Comentario',
	'comments' => 'Comentarios',
	'milestone' => 'Hito',
	'milestones' => 'Hitos',
	'task' => 'Tarea',
	'subtasks' => 'Subtareas',
	'tasks' => 'Tareas',
	'task list' => 'Tarea',
	'task lists' => 'Tareas',
	'tag' => 'Etiquetar',
	'tags' => 'Etiquetas',
	'attachment' => 'Adjunto',
	'attachments' => 'Adjunto',
	'object subscribers' => 'Suscriptores',
	'form' => 'Formulario',
	'forms' => 'Formularios',
	'file' => 'Archivo',
	'files' => 'Archivos',
	'file revision' => 'Revisión de archivo',
	'file revisions' => 'Revisión de archivos',
	'revision' => 'Revisión',
	'revisions' => 'Revisiones',
	'folder' => 'Carpeta',
	'folders' => 'Carpetas',
	'configuration category' => 'Configuración de categoría',
	'configuration categories' => 'Configuración de categorías',
	'handin' => 'Entregable',
	'handins' => 'Entregables',
	'emailunclassified' => 'Correo',
	'time' => 'Horas',
	'reporting' => 'Reportes',
	'modify object subscribers' => 'Modificar Subscriptores',
	'subscription modified successfully' => 'Subscriptores modificados exitosamente',
	'owner company' => 'Empresa propietaria',
	'client companies' => 'Empresas clientes',
	'open milestone' => 'Abrir hito',
	'open milestones' => 'Abrir hitos',
	'completed milestone' => 'Hito completado',
	'completed milestones' => 'Hitos completado',
	'late milestones' => 'Hito tardío',
	'late milestones and tasks' => 'Hitos y tareas atrasadas',
	'today milestones' => 'Hitos de hoy',
	'upcoming milestones' => 'Hitos recibidos',
	'completed task list' => 'Tarea completada',
	'completed task lists' => 'Tareas completadas',
	'open task list' => 'Abrir tarea',
	'open task lists' => 'Abrir tareas',
	'active project' => 'Espacio activo',
	'active projects' => 'Espacios activos',
	'finished project' => 'Espacio cerrado',
	'finished projects' => 'Espacios cerrados',
	'linked object' => 'Objeto vinculado',
	'linked objects' => 'Objetos vinculados',
	'important message' => 'Nota importante',
	'important messages' => 'Notas importantes',
	'important file' => 'Archivo importante',
	'important files' => 'Archivos importante',
	'parent task' => 'Tarea padre',
	'private message' => 'Nota privada',
	'private milestone' => 'Hito privado',
	'private task list' => 'Tareas privadas',
	'private comment' => 'Comentario privado',
	'private file' => 'Archivo privado',
	'file contents' => 'Contenido del archivo',
	'object reminders' => 'Recordatorios',
	'add object reminder' => 'Agregar recordatorio',
	'load file' => 'Cargar archivo',
	'create document' => 'Crear Documentos',
	'create presentation' => 'Crear Presentación',
	'urgent milestone' => 'Urgente',
	'the message' => 'la nota',
	'the email' => 'el correo',
	'the emailunclassified' => 'el correo',
	'the contact' => 'el contacto',
	'the company' => 'la empresa',
	'the event' => 'el evento',
	'the file' => 'el archivo',
	'the file revision' => 'la versión de archivo',
	'the file_revision' => 'la versión de archivo',
	'the task' => 'la tarea',
	'the milestone' => 'el hito',
	'the webpage' => 'el enlace',
	'the comment' => 'el comentario',
	'the user' => 'el usuario',
	'the project' => 'el espacio',
	'activity add' => '{1} agregó {0} {2}',
	'activity edit' => '{1} editó {0} {2}',
	'activity delete' => '{1} borró {0} {2}',
	'activity trash' => '{1} envió a la papelera {0} {2}',
	'activity untrash' => '{1} quitó de la papelera {0} {2}',
	'activity open' => '{1} abrió {0} {2}',
	'activity close' => '{1} cerró {0} {2}',
	'activity subscribe' => '{1} suscribió a {3} a {0} {2}',
	'activity unsubscribe' => '{1} desuscribió a {3} de {0} {2}',
	'activity tag' => '{1} etiquetó {0} {2} con las etiquetas {3}',
	'activity untag' => '{1} desetiquetó {0} {2}',
	'activity comment' => '{1} comentó {0} {2}:<br>    "{3}"',
	'activity link' => '{1} vinculó {0} {2} con {3} {4}',
	'activity unlink' => '{1} desvinculó {0} {2} de {3} {4}',
	'activity login' => '{0} inició sesión',
	'activity logout' => '{0} cerró sesión',
	'activity archive' => '{1} archivó {0} {2}',
	'activity unarchive' => '{1} desarchivó {0} {2}',
	'activity move from to' => '{1} movió {0} {2} de {3} a {4}',
	'activity move from' => '{1} movió {0} {2} de {3}',
	'activity move to' => '{1} movió {0} {2} a {3}',
	'activity move' => '{1} movió {0} {2}',
	'activity copy to' => '{1} copió {0} {2} a {3}',
	'activity copy' => '{1} copió {0} {2}',
	'activity read' => '{1} leyó {0} {2}',
	'activity download' => '{1} descargó {0} {2}',
	'activity checkout' => "{1} ha bloqueado {0} {2}",
    'activity checkin' => "{1} ha actualizado {0} {2}",

	'x users' => '{0} usuarios {1}',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_la/objects.php <==
<?php return array(
	'user' => 'Usuario',
	'group' => 'Grupo',
	'groups' => 'Grupos',
	'users' => 'Usuarios',
	'member' => 'Miembro',
	'members' => 'Miembros',
	'company' => 'Organización',
	'companies' => 'Organizaciones',
	'client' => 'Cliente',
	'clients' => 'Clientes',
	'package' => 'Paquete',
	'message' => 'Nota',
	'messages' => 'Notas',
	'comment' => 'Comentario',
	'comments' => 'Comentarios',
	'milestone' => 'Hito',
	'milestones' => 'Hitos',
	'task' => 'Tarea',
	'subtasks' => 'Subtareas',
	'tasks' => 'Tareas',
	'task list' => 'Tarea',
	'task lists' => 'Tareas',
	'timeslot' => 'timeslot',
	'tag' => 'Etiquetar',
	'tags' => 'Etiquetas',
	'attachment' => 'Adjunto',
	'attachments' => 'Adjunto',
	'object subscribers' => 'Subscriptores',
	'form' => 'Formulario',
	'forms' => 'Formularios',
	'file' => 'Documento',
	'files' => 'Documentos',
	'file revision' => 'Revisión de documento',
	'file revisions' => 'Revisión de documentos',
	'revision' => 'Revisión',
	'revisions' => 'Revisiones',
	'folder' => 'Carpeta',
	'folders' => 'Carpetas',
	'configuration category' => 'Configuración de categoría',
	'configuration categories' => 'Configuración de categorías',
	'handin' => 'Entregable',
	'handins' => 'Entregables',
	'emailunclassified' => 'Correo',
	'time' => 'Horas',
	'report' => 'Reporte',
	'reporting' => 'Reportes',
	'modify object subscribers' => 'Modificar Subscriptores',
	'subscription modified successfully' => 'Subscriptores modificados exitosamente',
	'owner company' => 'Organización propietaria',
	'client companies' => 'Organizaciones clientes',
	'open milestone' => 'Abrir hito',
	'open milestones' => 'Abrir hitos',
	'completed milestone' => 'Hito completado',
	'completed milestones' => 'Hitos completado',
	'late milestones' => 'Hito tardío',
	'late milestones and tasks' => 'Hitos y tareas atrasadas',
	'today milestones' => 'Hitos de hoy',
	'upcoming milestones' => 'Hitos recibidos',
	'completed task list' => 'Tarea completada',
	'completed task lists' => 'Tareas completadas',
	'open task list' => 'Abrir tarea',
	'open task lists' => 'Abrir tareas',
	'active project' => 'Espacio activo',
	'active projects' => 'Espacios activos',
	'finished project' => 'Espacio cerrado',
	'finished projects' => 'Espacios cerrados',
	'linked object' => 'Objeto vinculado',
	'linked objects' => 'Objetos vinculados',
	'important message' => 'Nota importante',
	'important messages' => 'Notas importantes',
	'important file' => 'Documento importante',
	'important files' => 'Documentos importante',
	'parent task' => 'Tarea padre',
	'private message' => 'Nota privada',
	'private milestone' => 'Hito privado',
	'private task list' => 'Tareas privadas',
	'private comment' => 'Comentario privado',
	'private file' => 'Documento privado',
	'file contents' => 'Contenido del documento',
	'object reminders' => 'Recordatorios',
	'add object reminder' => 'Agregar recordatorio',
	'load file' => 'Cargar documento',
	'create document' => 'Crear Documentos',
	'create presentation' => 'Crear Presentación',
	'urgent milestone' => 'Urgente',
	'the message' => 'la nota',
	'the email' => 'el correo',
	'the emailunclassified' => 'el correo',
	'the contact' => 'la persona',
	'the company' => 'la organización',
	'the event' => 'el evento',
	'the file' => 'el documento',
	'the file revision' => 'la versión de documento',
	'the file_revision' => 'la versión de documento',
	'the task' => 'la tarea',
	'the milestone' => 'el hito',
	'the webpage' => 'el enlace',
	'the comment' => 'el comentario',
	'the user' => 'el usuario',
	'the project' => 'el espacio',
	'the timeslot' => 'el tiempo de trabajo',
	'activity add' => '{1} agregó {0} {2}',
	'activity edit' => '{1} editó {0} {2}',
	'activity delete' => '{1} borró {0} {2}',
	'activity trash' => '{1} envió a la papelera {0} {2}',
	'activity untrash' => '{1} quitó de la papelera {0} {2}',
	'activity open' => '{1} abrió {0} {2}',
	'activity close' => '{1} cerró {0} {2}',
	'activity subscribe' => '{1} suscribió a {3} a {0} {2}',
	'activity unsubscribe' => '{1} desuscribió a {3} de {0} {2}',
	'activity tag' => '{1} etiquetó {0} {2} con las etiquetas {3}',
	'activity untag' => '{1} desetiquetó {0} {2}',
	'activity comment' => '{1} comentó {0} {2}:<br>    "{3}"',
	'activity link' => '{1} vinculó {0} {2} con {3} {4}',
	'activity unlink' => '{1} desvinculó {0} {2} de {3} {4}',
	'activity login' => '{0} inició sesión',
	'activity logout' => '{0} cerró sesión',
	'activity archive' => '{1} archivó {0} {2}',
	'activity unarchive' => '{1} desarchivó {0} {2}',
	'activity move from to' => '{1} movió {0} {2} de {3} a {4}',
	'activity move from' => '{1} movió {0} {2} de {3}',
	'activity move to' => '{1} movió {0} {2} a {3}',
	'activity move' => '{1} movió {0} {2}',
	'activity copy to' => '{1} copió {0} {2} a {3}',
	'activity copy' => '{1} copió {0} {2}',
	'activity read' => '{1} leyó {0} {2}',
	'activity download' => '{1} descargó {0} {2}',
	'activity checkout' => "{1} ha bloqueado {0} {2}",
    'activity checkin' => "{1} ha actualizado {0} {2}",

	'x users' => '{0} usuarios {1}',
); ?>
